@@ -1,12 +1,12 @@
-/// This is a simplified implementation of [rust-memcache](https://github.com/aisk/rust-memcache)
-/// ported for AsyncRead + AsyncWrite.
+//! This is a simplified implementation of [rust-memcache](https://github.com/aisk/rust-memcache)
+//! ported for AsyncRead + AsyncWrite.
 use core::fmt::Display;
 use futures::io::{AsyncBufReadExt, AsyncRead, AsyncReadExt, AsyncWrite, AsyncWriteExt, BufReader};
 use std::collections::HashMap;
 use std::io::{Error, ErrorKind};
 use std::marker::Unpin;
 
-pub struct Protocol<S: AsyncRead + AsyncWrite> {
+pub struct Protocol<S> {
     io: BufReader<S>,
 }
 
@@ -19,8 +19,8 @@ where
         Self { io: BufReader::new(io) }
     }
 
-    /// Returns the value for given key as bytes. If the value doesn't exist, `std::io::ErrorKind::NotFound` is returned.
-    pub async fn get<'a, K: Display>(&'a mut self, key: &'a K) -> Result<Vec<u8>, Error> {
+    /// Returns the value for given key as bytes. If the value doesn't exist, [`ErrorKind::NotFound`] is returned.
+    pub async fn get<K: Display>(&mut self, key: K) -> Result<Vec<u8>, Error> {
         // Send command
         let header = format!("get {}\r\n", key);
         self.io.get_mut().write_all(header.as_bytes()).await?;
@@ -55,11 +55,11 @@ where
         Ok(buffer)
     }
 
-    /// Returns values for multiple keys in a single call as a `HashMap` from keys to found values.
+    /// Returns values for multiple keys in a single call as a [`HashMap`] from keys to found values.
     /// If a key is not present in memcached it will be absent from returned map.
-    pub async fn get_multi<'a, K: AsRef<[u8]>>(
-        &'a mut self,
-        keys: &'a [K],
+    pub async fn get_multi<K: AsRef<[u8]>>(
+        &mut self,
+        keys: &[K],
     ) -> Result<HashMap<String, Vec<u8>>, Error> {
         // Send command
         let writer = self.io.get_mut();
@@ -111,11 +111,11 @@ where
         }
     }
 
-    /// Get up to `limit` keys which match the given prefix. Returns a HashMap from keys to found values.
+    /// Get up to `limit` keys which match the given prefix. Returns a [HashMap] from keys to found values.
     /// This is not part of the Memcached standard, but some servers implement it nonetheless.
-    pub async fn get_prefix<'a, K: Display>(
-        &'a mut self,
-        key_prefix: &'a K,
+    pub async fn get_prefix<K: Display>(
+        &mut self,
+        key_prefix: K,
         limit: Option<usize>,
     ) -> Result<HashMap<String, Vec<u8>>, Error> {
         // Send command
@@ -131,11 +131,11 @@ where
         self.read_many_values().await
     }
 
-    /// Add a key. If the value exist, `std::io::ErrorKind::AllreadyExists` is returned.
-    pub async fn add<'a, K: Display>(
-        &'a mut self,
-        key: &'a K,
-        val: &'a [u8],
+    /// Add a key. If the value exists, [`ErrorKind::AlreadyExists`] is returned.
+    pub async fn add<K: Display>(
+        &mut self,
+        key: K,
+        val: &[u8],
         expiration: u32,
     ) -> Result<(), Error> {
         // Send command
@@ -164,10 +164,10 @@ where
     }
 
     /// Set key to given value and don't wait for response.
-    pub async fn set<'a, K: Display>(
-        &'a mut self,
-        key: &'a K,
-        val: &'a [u8],
+    pub async fn set<K: Display>(
+        &mut self,
+        key: K,
+        val: &[u8],
         expiration: u32,
     ) -> Result<(), Error> {
         let header = format!("set {} 0 {} {} noreply\r\n", key, expiration, val.len());
@@ -179,13 +179,14 @@ where
     }
 
     /// Delete a key and don't wait for response.
-    pub async fn delete<'a, K: Display>(&'a mut self, key: &'a K) -> Result<(), Error> {
+    pub async fn delete<K: Display>(&mut self, key: K) -> Result<(), Error> {
         let header = format!("delete {} noreply\r\n", key);
         self.io.write_all(header.as_bytes()).await?;
         self.io.flush().await?;
         Ok(())
     }
 
+    /// Return the version of the remote server.
     pub async fn version(&mut self) -> Result<String, Error> {
         self.io.write_all(b"version\r\n").await?;
         self.io.flush().await?;
@@ -205,6 +206,7 @@ where
         Ok(version.to_string())
     }
 
+    /// Delete all keys from the cache.
     pub async fn flush(&mut self) -> Result<(), Error> {
         self.io.write_all(b"flush_all\r\n").await?;
         self.io.flush().await?;
